Zonis
---

A coro based callback system for many to one IPC setups.

`pip install zonis`

See the [examples](https://github.com/Skelmis/Zonis/tree/master/exampleshttps://github.com/Skelmis/Zonis/tree/master/examples) for simple use cases.